#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-0ffa51594095a53764b8bdc650dc6fa5
key: gnuid_9LiyrgaLwmbEcvoD479OYo
license: GPL-3
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
author: John Millikin
exposed: True
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/gnuidn-0.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-9LiyrgaLwmbEcvoD479OYo
extra-libraries:
    idn idn
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
